# What is Nano++?

NPP, or Nano++ for short is a text editor designed for those vaguely familiar with the Nano text editor, but are frustrated with the shortcomings of it - and don't want to go through learning Vim or Emacs.

For example npp includes more familiar text selection, copying to clipboard and is a whole LETTER shorter than typing out nano.

Installation should be fairly simple:

Initialise a virtual environment and `pip install nanoplusplus`

Now when you have that virtual environment activated, NPP will be available to use!

# How Exactly Does it Differ From Nano?

Like this:

![General overview of NanoPlusPlus](assets/general%20overview.gif)

Which looks **remarkably similar** to Nano, which is intentional!

The difference being the ability to hold shift and move the arrow keys to select chunks of text like most other text editors (instead of Nano's convoluted mark hotkey systems):

![Selecting via arrow keys](assets/selection.gif)

As well as using the standard copy and paste hotkeys (which persists to your clipboard as well)!

![Copying and Pasting](assets/clipboarding.gif)